# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .guideline import Guideline
from .connection_kind_dto import ConnectionKindDto
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class GuidelineConnection(UniversalBaseModel):
    id: str
    source: Guideline
    target: Guideline
    kind: ConnectionKindDto
    indirect: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
